using System.Collections.Generic;
using Adguard.Core.Api;
using Adguard.Core.Api.Certificate;
using Adguard.Core.Api.Driver;
using Adguard.Core.Api.ProxyServer.Configs;
using NUnit.Framework;

namespace Adguard.Core.Tests.TestApi
{
    [TestFixture]
    public class TestConfigurations
    {
        [Test]
        public void TestEqualityFilteringApplication()
        {
            FilteredApplication config1 = new FilteredApplication
            {
                AdBlockingEnabled = false,
                AbsolutePath = "absolutePath",
                ExecutableNames = new List<string>(),
                FileDescription = "newAppDescription",
                HttpsFilteringEnabled = false,
                Name = "newAppName"
            };
            FilteredApplication config2 = new FilteredApplication
            {
                AdBlockingEnabled = false,
                AbsolutePath = "absolutePath",
                ExecutableNames = new List<string>(),
                FileDescription = "newAppDescription",
                HttpsFilteringEnabled = false,
                Name = "newAppName"
            };
            Assert.IsTrue(config1.Equals(config2));

            config2.HttpsFilteringEnabled = true;
            // We don't take the "HttpsFilteringEnabled" property into the account,
            // because changes in this value are handled on the App side, and mustn't lead
            // to the proxy server reloading or even reconfiguring
            Assert.IsTrue(config1.Equals(config2));
            config2.HttpsFilteringEnabled = false;

            config2.AdBlockingEnabled = true;
            Assert.IsFalse(config1.Equals(config2));
            config2.AdBlockingEnabled = false;

            config2.AbsolutePath = "another path";
            Assert.IsFalse(config1.Equals(config2));
            config2.AbsolutePath = "absolutePath";

            config2.ExecutableNames.Add("EXE");
            Assert.IsFalse(config1.Equals(config2));
            config2.ExecutableNames.Clear();

            config2.FileDescription = "another description";
            Assert.IsFalse(config1.Equals(config2));
            config2.FileDescription = "newAppDescription";

            config2.Name = "another name";
            Assert.IsFalse(config1.Equals(config2));
        }
    }
}